import java.awt.event.*;
import javax.swing.Timer;

/** The Controller class of the Clock application 
 * contains event handler (which implements ActionListener as 
 * an anonymous inner class) for dealing with Time.
 * Some (code analysis tools) might say the Controller isn't
 * necessary because other objects do not use it. This is
 * wrong &mdash; Controller generates events which affect 
 * model {@link Model}
 * @author Ian Barnes (2005 original version)
 * @author abx (2007 adopted for a GUI assignment and javadoc tags added)
 * @see Model
 * @see View
 */


public class Controller {
    
    /** event handler which calls to repaint the clock panel*/
    ActionListener listener;
    
    /** timer to maintain the clock count */
    Timer timer;
    
    /** model maintains value of hours, minutes and seconds and call the update*/
    Model model;
    
    /** view defines the panel on which every thing is drawn */    
    View view;
    
    /** creates controller linked to view and model */
    public Controller(Model m, View v) {
        model = m;
        view = v;
        
        listener = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                model.update();
            }
        };
        
        timer = new Timer(100, listener);
        timer.start();
    }
}